@@ -230,7 +230,10 @@ class PiNapsController:
             buffer += [ord(c) for c in self._UART.read(numWaiting)]
             return buffer
         if self._interface == self.Interface.I2C:
-            return self._I2C.readRegister(self._I2C.registers.RHR)
+            buffer = []
+            for i in range(self._I2C.dataWaiting()):
+                buffer.append(self._I2C.readRegister(self._I2C.registers.RHR))
+            return buffer
         if self._interface == self.Interface.NONE:
             raise Exception("No interface setup. Make sure a chosen interface has been setup.")
             
